OGBWikiKG
=========

.. currentmodule:: pykeen.datasets

.. autoclass:: OGBWikiKG
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~OGBWikiKG.name

   .. rubric:: Attributes Documentation

   .. autoattribute:: name
